@@ -5,7 +5,7 @@ import click
 import msal
 import requests
 
-from .config import SAVED_CONFIG_PATH, api_config, SAVED_MSAL_TOKEN_CACHE_PATH
+from .config import SAVED_CONFIG_PATH, SAVED_MSAL_TOKEN_CACHE_PATH, api_config
 from .token_cache import token_cache
 
 SCOPES = [
