@@ -37,7 +37,13 @@ def get_author_name(user):
 
 
 def get_python_version():
-    version_output = subprocess.run(["python3", "--version"], stdout=subprocess.PIPE)
+    try:
+        version_output = subprocess.run(["python3", "--version"], shell=True, check=True, stdout=subprocess.PIPE)
+    except subprocess.CalledProcessError as e:
+        print("Error while trying to run `python3 --version`. Please make sure that python is installed and `python3` "
+              "is available in path.")
+        raise
+
     return re.search(r"(\d+\.\d+.\d+)", version_output.stdout.decode("utf-8")).group(1)
 
 
